@@ -5,7 +5,8 @@ binary_model<-function(command) {
     write.table(param,file="input",row.names=F,col.names=F,quote=F)
     system(command)
     file.remove("input")
-    read.table("output",header=F)
+    output=read.table("output",header=F)
     file.remove("output")
+    output
   }
 }
